# Copyright (c) 2013 OpenStack Foundation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.


"""Exceptions used by Arista ML2 Mechanism Driver."""

from neutron_lib import exceptions

from networking_arista._i18n import _


class AristaRpcError(exceptions.NeutronException):
    message = _('%(msg)s')


class AristaConfigError(exceptions.NeutronException):
    message = _('%(msg)s')


class AristaServicePluginRpcError(exceptions.NeutronException):
    message = _('%(msg)s')


class AristaServicePluginConfigError(exceptions.NeutronException):
    message = _('%(msg)s')


class AristaSecurityGroupError(exceptions.NeutronException):
    message = _('%(msg)s')
